==> jupyter_power_usage-1.1.1.tar.gz: jupyter_power_usage-1.1.1/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 1.1.1

([Full Changelog](https://github.com/mahendrapaipuri/jupyter-power-usage/compare/v1.1.0...e4bed2566bee4ad972523c2fa1dced4121dbca9e))

### Bugs fixed

- Force new instance of  `ASyncHTTPclient` [#10](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/10) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/mahendrapaipuri/jupyter-power-usage/graphs/contributors?from=2024-04-03&to=2024-04-10&type=c))

[@mahendrapaipuri](https://github.com/search?q=repo%3Amahendrapaipuri%2Fjupyter-power-usage+involves%3Amahendrapaipuri+updated%3A2024-04-03..2024-04-10&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 1.1.0

([Full Changelog](https://github.com/mahendrapaipuri/jupyter-power-usage/compare/v1.0.0...43f5a12b352e65bd810d75bb06608e605836ca4c))

### Enhancements made

- Electricity Maps Support [#9](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/9) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Bugs fixed

- Fix CPU share estimation [#7](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/7) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Maintenance and upkeep improvements

- Fix CPU share estimation [#7](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/7) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/mahendrapaipuri/jupyter-power-usage/graphs/contributors?from=2023-10-12&to=2024-04-03&type=c))

[@mahendrapaipuri](https://github.com/search?q=repo%3Amahendrapaipuri%2Fjupyter-power-usage+involves%3Amahendrapaipuri+updated%3A2023-10-12..2024-04-03&type=Issues)

## 1.0.0

([Full Changelog](https://github.com/mahendrapaipuri/jupyter-power-usage/compare/v0.1.1...62b1ee6d0ed0a662330c0156807b07e493eeb85a))

### Enhancements made

- Upgrade to JupyterLab 4 [#4](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/4) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Maintenance and upkeep improvements

- Upgrade to JupyterLab 4 [#4](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/4) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/mahendrapaipuri/jupyter-power-usage/graphs/contributors?from=2023-10-12&to=2023-10-12&type=c))

[@mahendrapaipuri](https://github.com/search?q=repo%3Amahendrapaipuri%2Fjupyter-power-usage+involves%3Amahendrapaipuri+updated%3A2023-10-12..2023-10-12&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/mahendrapaipuri/jupyter-power-usage/compare/3b718a62b80160933904e991b2ebde25598434a5...d8fc444ef94e53dab89ce84192927d215558a82e))

### Maintenance and upkeep improvements

- Update `package.json` config and README [#2](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/2) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))
- Add CI workflows [#1](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/1) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/mahendrapaipuri/jupyter-power-usage/graphs/contributors?from=2023-10-01&to=2023-10-12&type=c))

[@mahendrapaipuri](https://github.com/search?q=repo%3Amahendrapaipuri%2Fjupyter-power-usage+involves%3Amahendrapaipuri+updated%3A2023-10-01..2023-10-12&type=Issues)

==> jupyter_power_usage-1.2.0.tar.gz: jupyter_power_usage-1.2.0/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 1.2.0

([Full Changelog](https://github.com/mahendrapaipuri/jupyter-power-usage/compare/v1.1.1...903a5deb29fe761cb5da4a1d8a06533ea77bd458))

### Enhancements made

- Allow toggling indicator bar [#11](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/11) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/mahendrapaipuri/jupyter-power-usage/graphs/contributors?from=2024-04-10&to=2025-04-27&type=c))

[@mahendrapaipuri](https://github.com/search?q=repo%3Amahendrapaipuri%2Fjupyter-power-usage+involves%3Amahendrapaipuri+updated%3A2024-04-10..2025-04-27&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 1.1.1

([Full Changelog](https://github.com/mahendrapaipuri/jupyter-power-usage/compare/v1.1.0...e4bed2566bee4ad972523c2fa1dced4121dbca9e))

### Bugs fixed

- Force new instance of `ASyncHTTPclient` [#10](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/10) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/mahendrapaipuri/jupyter-power-usage/graphs/contributors?from=2024-04-03&to=2024-04-10&type=c))

[@mahendrapaipuri](https://github.com/search?q=repo%3Amahendrapaipuri%2Fjupyter-power-usage+involves%3Amahendrapaipuri+updated%3A2024-04-03..2024-04-10&type=Issues)

## 1.1.0

([Full Changelog](https://github.com/mahendrapaipuri/jupyter-power-usage/compare/v1.0.0...43f5a12b352e65bd810d75bb06608e605836ca4c))

### Enhancements made

- Electricity Maps Support [#9](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/9) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Bugs fixed

- Fix CPU share estimation [#7](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/7) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Maintenance and upkeep improvements

- Fix CPU share estimation [#7](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/7) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/mahendrapaipuri/jupyter-power-usage/graphs/contributors?from=2023-10-12&to=2024-04-03&type=c))

[@mahendrapaipuri](https://github.com/search?q=repo%3Amahendrapaipuri%2Fjupyter-power-usage+involves%3Amahendrapaipuri+updated%3A2023-10-12..2024-04-03&type=Issues)

## 1.0.0

([Full Changelog](https://github.com/mahendrapaipuri/jupyter-power-usage/compare/v0.1.1...62b1ee6d0ed0a662330c0156807b07e493eeb85a))

### Enhancements made

- Upgrade to JupyterLab 4 [#4](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/4) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Maintenance and upkeep improvements

- Upgrade to JupyterLab 4 [#4](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/4) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/mahendrapaipuri/jupyter-power-usage/graphs/contributors?from=2023-10-12&to=2023-10-12&type=c))

[@mahendrapaipuri](https://github.com/search?q=repo%3Amahendrapaipuri%2Fjupyter-power-usage+involves%3Amahendrapaipuri+updated%3A2023-10-12..2023-10-12&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/mahendrapaipuri/jupyter-power-usage/compare/3b718a62b80160933904e991b2ebde25598434a5...d8fc444ef94e53dab89ce84192927d215558a82e))

### Maintenance and upkeep improvements

- Update `package.json` config and README [#2](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/2) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))
- Add CI workflows [#1](https://github.com/mahendrapaipuri/jupyter-power-usage/pull/1) ([@mahendrapaipuri](https://github.com/mahendrapaipuri))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/mahendrapaipuri/jupyter-power-usage/graphs/contributors?from=2023-10-01&to=2023-10-12&type=c))

[@mahendrapaipuri](https://github.com/search?q=repo%3Amahendrapaipuri%2Fjupyter-power-usage+involves%3Amahendrapaipuri+updated%3A2023-10-01..2023-10-12&type=Issues)
